==> webkit2gtk_2.26.4.orig.tar.xz: webkitgtk-2.26.4/Source/WebCore/Modules/webgpu/GPUCanvasContext.h <==
/*
 * Copyright (C) 2018 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEBGPU)

#include "GPUBasedCanvasRenderingContext.h"
#include "HTMLCanvasElement.h"
#include "WebGPUSwapChain.h"
#include <wtf/RefPtr.h>

namespace WebCore {

struct WebGPUSwapChainDescriptor;

class GPUCanvasContext final : public GPUBasedCanvasRenderingContext {
    WTF_MAKE_ISO_ALLOCATED(GPUCanvasContext);
public:
    static std::unique_ptr<GPUCanvasContext> create(CanvasBase&);

    HTMLCanvasElement& canvas() const { return downcast<HTMLCanvasElement>(canvasBase()); }

    Ref<WebGPUSwapChain> configureSwapChain(const WebGPUSwapChainDescriptor&);

private:
    GPUCanvasContext(CanvasBase&);

    // GPUBasedCanvasRenderingContext
    bool isWebGPU() const final { return true; }
    PlatformLayer* platformLayer() const final;
    void reshape(int width, int height) final;
    void markLayerComposited() final;
    const char* activeDOMObjectName() const final { return "GPUCanvasContext"; }
    // FIXME: Stubs.
    bool hasPendingActivity() const final { return false; }
    void stop() final { }
    bool canSuspendForDocumentSuspension() const final { return false; }

    RefPtr<WebGPUSwapChain> m_swapChain;
};

} // namespace WebCore

SPECIALIZE_TYPE_TRAITS_CANVASRENDERINGCONTEXT(WebCore::GPUCanvasContext, isWebGPU())

#endif // ENABLE(WEBGPU)

==> webkit2gtk_2.32.4.orig.tar.xz: webkitgtk-2.32.4/Source/WebCore/Modules/webgpu/GPUCanvasContext.h <==
/*
 * Copyright (C) 2018 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#if ENABLE(WEBGPU)

#include "GPUBasedCanvasRenderingContext.h"
#include "HTMLCanvasElement.h"
#include "WebGPUSwapChain.h"
#include <wtf/RefPtr.h>

namespace WebCore {

struct WebGPUSwapChainDescriptor;

class GPUCanvasContext final : public GPUBasedCanvasRenderingContext {
    WTF_MAKE_ISO_ALLOCATED(GPUCanvasContext);
public:
    static std::unique_ptr<GPUCanvasContext> create(CanvasBase&);

    HTMLCanvasElement& canvas() const { return downcast<HTMLCanvasElement>(canvasBase()); }

    WebGPUSwapChain* swapChain() const { return m_swapChain.get(); }
    Ref<WebGPUSwapChain> configureSwapChain(const WebGPUSwapChainDescriptor&);

private:
    GPUCanvasContext(CanvasBase&);

    // GPUBasedCanvasRenderingContext
    bool isWebGPU() const final { return true; }
    PlatformLayer* platformLayer() const final;
    void reshape(int width, int height) final;
    void prepareForDisplayWithPaint() final;
    void paintRenderingResultsToCanvas() final;

    // ActiveDOMObject.
    const char* activeDOMObjectName() const final { return "GPUCanvasContext"; }
    // FIXME: Stubs.
    void stop() final { }

    bool m_isDisplayingWithPaint { false };
    RefPtr<WebGPUSwapChain> m_swapChain;
};

} // namespace WebCore

SPECIALIZE_TYPE_TRAITS_CANVASRENDERINGCONTEXT(WebCore::GPUCanvasContext, isWebGPU())

#endif // ENABLE(WEBGPU)
